# Contributors

- Marius Müller <marius.mueller@physik.uni-giessen.de>
- Florian Dobener <florian.dobener@physik.hu-berlin.de>

# Acknowledgements

- Olivier Castany and C. Molinaro [Berreman4x4](https://github.com/Berreman4x4/Berreman4x4)
- Solver2x2 based on Steve Byrnes' [tmm](https://github.com/sbyrnes321/tmm)
- Mikhail Polyanskiy's [refractiveindex.info database](https://github.com/polyanskiy/refractiveindex.info-database) and Pavel Dmitriev's [pyTMM](https://github.com/kitchenknif/PyTMM) for his importer script for the database
